<?php
/*
Plugin Name: Fotherplot
Version: 0.0.3
Plugin URI: http://www.tomfotherby.com/Websites/Fotherplot
Description: A function for listing and plotting your data against time using the Google charts API. Originally used to plot my weight by using a custom field called "weight" in posts.
Author: Tom Fotherby
Author URI: http://www.tomfotherby.com
*/

function plotDataAgainstTime($customFieldName,$units="kgs",$showGraph=1,$showList=1) {

 global $wpdb, $PHP_SELF;
 setlocale(LC_ALL,WPLANG); // set localization language
 
 // Query the database for the posts that contain this custom field
 $query_string = "
 SELECT *
 FROM $wpdb->posts
 LEFT JOIN $wpdb->postmeta ON ($wpdb->posts.ID = $wpdb->postmeta.post_id)
 WHERE $wpdb->postmeta.meta_key = '$customFieldName'
 AND $wpdb->posts.post_status = 'publish'
 AND $wpdb->posts.post_type = 'post'
 ORDER BY $wpdb->posts.post_date ASC
 ";

 // List the posts
 $series_posts = $wpdb->get_results($query_string, OBJECT);

 $outputText = "";
 $googleChartDataY = "";
 $googleChartDataX = "";
 $googleChartLabsX = "";
 $firstDate = "";
 $lastDate = "";
 $lastDay = 0;
 $minDataVal = 1000;
 $maxDataVal = 0;
 $numOfXLabs = 5;
 $numOfPoints = sizeof($series_posts);
 $labSpacing = ceil($numOfPoints / $numOfXLabs);
 $count = 0;

echo '<p>';

 if ($series_posts):
   foreach ($series_posts as $post):
   	   if ($firstDate == "")
	      $firstDate = strtotime($post->post_date);

     	   $dayDiff = round((strtotime($post->post_date)-$firstDate) / (60 * 60 * 24));
	   if ($dayDiff > $lastDay) {
	      $lastDay = $dayDiff;
	      $lastDate = strtotime($post->post_date);
	   }

	   $dataVal = $post->meta_value;
	   if ($dataVal < $minDataVal)
	      $minDataVal = $dataVal;
	   if ($dataVal > $maxDataVal)
	      $maxDataVal = $dataVal;

	   // Build a list of X labels (but not too many)
	   if ($count == 0 || $count%$labSpacing == 0)
	      $googleChartLabsX .= "|". date("d/M/y",strtotime($post->post_date));

   	   //echo '<li>Date: ' . $post->post_date . ', ID: ' . $post->ID . ', title: ' . $post->post_title . ', MetaKey: ' . $post->meta_key . ', value: ' . $post->meta_value;

   	   $outputText = "<li>" . date("F j, Y",strtotime($post->post_date)) . ": {$dataVal}{$units}</li>" . $outputText;
	   $googleChartDataY .= $post->meta_value . ",";
	   $googleChartDataX .= $dayDiff . ",";

	   $count++;
   endforeach;

   $chartType    = "&cht=lxy";          // Line chart with x,y co-ordinates
   $chartSize    = "&chs=450x300";
   $chartMargins = "&chma=10,10,10,10";
   $axisScale    = "&chds=0,$lastDay,".$minDataVal.",".$maxDataVal;
   $axisGrid     = "&chg=0,5";
   //$axisLabels   = "&chxt=y&chxr=0,$minDataVal,$maxDataVal";  // Specify Range
   $axisLabels   = "&chxt=y,x&chxl=0:|$minDataVal|".((($maxDataVal-$minDataVal)*0.2)+$minDataVal)."|".((($maxDataVal-$minDataVal)*0.4)+$minDataVal)."|".((($maxDataVal-$minDataVal)*0.6)+$minDataVal)."|".((($maxDataVal-$minDataVal)*0.8)+$minDataVal)."|$maxDataVal|1:{$googleChartLabsX}";
   $dataLabels   = "&chm=D,FF0000,0,-1,1";    // Display a red line
   $dataLabels  .= "|o,000000,0,-1,4";        // Display a dot at each plot
   $dataLabels  .= "|N,000000,0,-1,9";        // Display the X-axis value for each point
   //$dataLabels  .= "|N*f0x*,000000,0,-1,9"; // Display the 'Y' value for each point
   $dataPoints   = "&chd=t:".substr($googleChartDataX,0,-1)."|".substr($googleChartDataY,0,-1);

   if ($showGraph)
      echo "<center><img src=\"http://chart.apis.google.com/chart?{$chartType}{$chartSize}{$chartMargins}{$axisScale}{$axisGrid}{$axisLabels}{$dataLabels}{$dataPoints}\" /></center>";

   if ($showList)
      echo "<p><p><ul>$outputText</ul>";

 endif;

}
?>